from setuptools import setup

setup(name='prct_distributions',
      version='1.0',
      description='Gaussian distributions',
      packages=['prct_distributions'],
      author='siva kumar pabbisetty',
      author_email='pabbisettyssivakumar@gmail.com',
      zip_safe=False)
